import pyfits


class CALIFA_cube(object):
    def __init__(self, data=None,  error = None, mask = None,  error_weight=None, header = None):
        if data==None:
            self._data = None
        else:
            self._data = data
            self._res_elements = data.shape[0]
            self._dim_y = data.shape[1]
            self._dim_x = data.shape[2]
        if error==None:
            self._error = None
        else:
            self._error = error
        
        if error_weight==None:
            self._error_weight = None
        else:
            self._error_weight = error_weight
            
        if mask==None:
            self._mask = None
        else:
            self._mask = mask
            
        if header==None:
            self._header = None
        else:
            self._header = header
            
    def load_CALIFA(self, file):
        hdu = pyfits.open(file)
        self._data = hdu[0].data
        self._res_elements = self._data.shape[0]
        self._dim_y = self._data.shape[1]
        self._dim_x = self._data.shape[2]
        self._header = hdu[0].header
        if len(hdu)>1:
            for i in range(1, len(hdu)):
                if hdu[i].header['EXTNAME'].split()[0]=='ERROR':
                    self._error = hdu[i].data
                elif hdu[i].header['EXTNAME'].split()[0]=='BADPIX':
                    self._mask = hdu[i].data.astype('bool')
                elif hdu[i].header['EXTNAME'].split()[0]=='ERRWEIGHT':
                    self._error_weight = hdu[i].data
                    
    def write_CALIFA_split(self, prefix):
        hdu = pyfits.PrimaryHDU(self._data)
        hdu.header = self._header
        hdu.writeto(prefix+'_data.fits', clobber=True)
        
        hdu = pyfits.PrimaryHDU(self._error)
        hdu.header = self._header
        hdu.writeto(prefix+'_error.fits', clobber=True)
        
        hdu = pyfits.PrimaryHDU(self._mask.astype('uint16'))
        hdu.header = self._header
        hdu.writeto(prefix+'_mask.fits', clobber=True)
        
        hdu = pyfits.PrimaryHDU(self._error_weight)
        hdu.header = self._header
        hdu.writeto(prefix+'_err_weight.fits', clobber=True)
        
